@@ -2,6 +2,6 @@
 #define VM_LABEL_H
 
 char* new_vm_label();
-char* current_vm_label();
+void free_vm_label( char* vm_label );
 
 #endif /* VM_LABEL_H */
